@@ -1,7 +1,7 @@
-# Copyright 2001 by Roger S. Bivand. 
+# Copyright 2001-3 by Roger S. Bivand. 
 #
 
-knearneigh <- function(x, k=1)
+knearneigh <- function(x, k=1, lonlat=FALSE)
 {
     if (!is.numeric(x)) stop("Data non-numeric")
     if (!is.matrix(x)) stop("Data not in matrix form")
@@ -9,6 +9,7 @@ knearneigh <- function(x, k=1)
     if (!is.double(x)) x <- as.double(x)
     np <- nrow(x)
     dimension <- ncol(x)
+    if (dimension > 2) stop("Only 2D data accepted")
     if (k >= np) stop("Fewer data points than k")
     xx <- x[,1]
     if (dimension > 1) for (i in 2:dimension) xx <- c(xx, x[,i])
@@ -17,7 +18,7 @@ knearneigh <- function(x, k=1)
     z <- .C("knearneigh", k=as.integer(k), np=as.integer(np),
         dimension=as.integer(dimension),
         xx=as.double(xx), nn=as.integer(nn), dnn=as.double(dnn),
-	PACKAGE="spdep")
+	as.integer(lonlat), PACKAGE="spdep")
     res <- list(nn=matrix(z$nn, np, k, byrow=TRUE), np=np, k=k,
     	dimension=dimension, x=x)
     class(res) <- "knn"
